@@ -2,67 +2,46 @@
 Perl generator functions for the various wxSizerS
 
 @copyright: 2002-2004 D.H. aka crazyinsomniac on sourceforge.net
-@copyright: 2013-2015 Carsten Grohmann
+@copyright: 2013-2016 Carsten Grohmann
+@copyright: 2017 Dietmar Schwertberger
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
-
 import common
-from edit_sizers import BaseSizerBuilder
+from .edit_sizers import BaseSizerBuilder
 
 
 class BasePerlSizerBuilder(BaseSizerBuilder):
-    """\
-    Perl base class for all sizer code generators
-    """
-
+    "Perl base class for all sizer code generators"
     language = 'perl'
 
     tmpl_SetSizer = '%(parent_widget)s->SetSizer(%(sizer_name)s);\n'
     tmpl_Fit = '%(sizer_name)s->Fit(%(parent_widget)s);\n'
-    tmpl_SetSizeHints = '%(sizer_name)s->SetSizeHints(' \
-                        '%(parent_widget)s);\n'
-    tmpl_StaticBox = '$self->{%s_staticbox}'
+    tmpl_SetSizeHints = '%(sizer_name)s->SetSizeHints(%(parent_widget)s);\n'
 
     def _get_wparent(self, obj):
-        if not obj.parent.is_toplevel:
-            parent = '$self->{%s}' % obj.parent.name
+        while obj.is_sizer:
+            obj = obj.node.parent.widget
+        if not obj.is_toplevel:
+            parent = '$self->{%s}' % obj.name
         else:
             parent = '$self'
         return parent
 
-# end of class BasePerlSizerBuilder
-
 
 class PerlBoxSizerBuilder(BasePerlSizerBuilder):
     klass = 'wxBoxSizer'
-    init_stmt = [
-        '%(sizer_name)s = %(klass)s->new(%(orient)s);\n'
-        ]
-
-# end of class PerlBoxSizerBuilder
+    tmpl = '%(sizer_name)s = %(klass)s->new(%(orient)s);\n'
 
 
 class PerlStaticBoxSizerBuilder(BasePerlSizerBuilder):
     klass = 'wxStaticBoxSizer'
-    init_stmt = [
-        '%(staticbox_name)s = %(wxStaticBox)s->new('
-            '%(parent_widget)s, wxID_ANY, %(label)s );\n',
-        '%(sizer_name)s = %(klass)s->new(%(staticbox_name)s, %(orient)s);\n',
-        '%(staticbox_name)s->Lower();\n',
-        ]
-
-# end of class PerlStaticBoxSizerBuilder
+    tmpl = '%(sizer_name)s = %(klass)s->new(Wx::StaticBox->new(%(parent_widget)s, wxID_ANY, %(label)s), %(orient)s);\n'
 
 
 class PerlGridSizerBuilder(BasePerlSizerBuilder):
     klass = 'wxGridSizer'
-    init_stmt = [
-        '%(sizer_name)s = %(klass)s->new(%(rows)s, %(cols)s, '
-            '%(vgap)s, %(hgap)s);\n'
-        ]
-
-# end of class PerlGridSizerBuilder
+    tmpl = '%(sizer_name)s = %(klass)s->new(%(rows)s, %(cols)s, %(vgap)s, %(hgap)s);\n'
 
 
 class PerlFlexGridSizerBuilder(PerlGridSizerBuilder):
@@ -71,7 +50,19 @@ class PerlFlexGridSizerBuilder(PerlGridSizerBuilder):
     tmpl_AddGrowableRow = '%(sizer_name)s->AddGrowableRow(%(row)s);\n'
     tmpl_AddGrowableCol = '%(sizer_name)s->AddGrowableCol(%(col)s);\n'
 
-# end of class PerlFlexGridSizerBuilder
+
+class PerlGridBagSizerBuilder(PerlFlexGridSizerBuilder):
+    klass = 'wxGridBagSizer'
+    tmpl = '%(sizer_name)s = %(klass)s->new(%(vgap)s, %(hgap)s);\n'
+
+
+import wcodegen
+
+class PerlSizerSlotGenerator(wcodegen.PerlWidgetCodeWriter):
+    # spacers and empty sizer slots are generally handled by a hack:
+    # The the implementations of add_sizeritem() contains more details.
+    # The code generation code is already implemented in base class.
+    pass
 
 
 def initialize():
@@ -80,6 +71,7 @@ def initialize():
     cn['EditStaticBoxSizer'] = 'wxStaticBoxSizer'
     cn['EditGridSizer'] = 'wxGridSizer'
     cn['EditFlexGridSizer'] = 'wxFlexGridSizer'
+    cn['EditGridBagSizer'] = 'wxGridBagSizer'
 
     plgen = common.code_writers.get("perl")
     if plgen:
@@ -88,3 +80,6 @@ def initialize():
         awh('wxStaticBoxSizer', PerlStaticBoxSizerBuilder())
         awh('wxGridSizer', PerlGridSizerBuilder())
         awh('wxFlexGridSizer', PerlFlexGridSizerBuilder())
+        awh('wxGridBagSizer', PerlGridBagSizerBuilder())
+
+    common.register('perl', "sizerslot", PerlSizerSlotGenerator("sizerslot"))
