@@ -1,33 +1,34 @@
 """\
 Functions to import modules
 
-@copyright: 2015 Carsten Grohmann
+@copyright: 2016 Carsten Grohmann
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
 import logging
 import os
+import re
 import sys
 import zipfile
+from collections import OrderedDict
 
 import common
 import config
 
+rec_section = re.compile(r'\[(?P<section>[^]]+)\]')
+"""Regex tp match section headers"""
 
-def load_widgets_from_dir(widget_dir, submodule=''):
+rec_module = re.compile(r'^(?P<module>\w+)')
+"""Regex to match modules"""
+
+
+def load_widgets_from_dir(widget_dir, submodule='',
+                          default_section='not_set'):
     """\
-    Load and initialise the all widgets listed in widgets.txt in the given
-    directory.
+    Load and initialise the all widgets listed in widgets.txt in the given directory.
 
-    The names of the modules to import, are read from the file widgets.txt.
-
-    If you need to import a submodule instead, just specify the name of the
-    submodule and "<module name>.<submodule>" will be imported. This is
-    useful to import language specific code generators.
-
-    If wxGlade run in the GUI mode, the imported module returns a
-    wxBitmapButton object. A list of such objects will be returned. In batch
-    mode or if submodules are imported, an empty list will be returned.
+    If you need to import a submodule instead, just specify the name of the submodule and "<module name>.<submodule>"
+    will be imported. This is useful to import language specific code generators.
 
     @param widget_dir: Directory to search for widgets
     @type widget_dir:  str
@@ -35,103 +36,123 @@ def load_widgets_from_dir(widget_dir, submodule=''):
     @param submodule: Submodule to import
     @type submodule:  str
 
-    @rtype: list
+    @param default_section: Section name to group all widgets, if no section has been found
+    @type default_section: str
+
+    @return: In GUI-Mode: a dict with module sections as key and assigned list of wxBitmapButtons, the dict is empty
+             in batch mode.
+    @rtype:  OrderedDict
 
     @see: L{import_module()}
     @see: L{config.use_gui} - for "GUI" or "batch" mode
     """
-    buttons = []
+    buttons = OrderedDict()
 
     # language code generators e.g. perl_codegen
     widgets_filename = os.path.join(widget_dir, 'widgets.txt')
-    module_list = _get_modulenames_from_file(widgets_filename)
+    module_info = _modulenames_from_file(widgets_filename, default_section)
 
-    if module_list and config.use_gui and not submodule.endswith('_codegen'):
+    if module_info and config.use_gui and not submodule.endswith('_codegen'):
         if submodule:
-            logging.info(_('Loading "%s" modules from %s:'),
-                         submodule, widgets_filename)
+            logging.info(_('Loading "%s" modules from %s:'), submodule, widgets_filename)
         else:
             logging.info(_('Loading widgets from %s:'), widgets_filename)
 
-    for module_name in module_list:
-        if submodule:
-            fqmn = "%s.%s" % (module_name, submodule)
-        else:
-            fqmn = "%s" % module_name
+    for section, module_names in module_info.items():
+        buttons[section] = []
 
-        # step 1: import widget module
-        module = import_module(widget_dir, fqmn)
-        if not module:
-            # error already logged
-            continue
-
-        # step 2: use individual initialisation if available
-        if hasattr(module, 'initialize'):
-            button = module.initialize()
-            if config.use_gui and button:
-                buttons.append(button)
-
-        # step 3: import and initialise Python codegen as well as widget
-        #         GUI elements
-        elif not submodule:
-            result, button = _init_codegen_gui(widget_dir, module_name)
-            if not result:
+        for module_name in module_names:
+            if submodule:
+                fqmn = "%s.%s" % (module_name, submodule)
+            else:
+                fqmn = "%s" % module_name
+    
+            # step 1: import widget module
+            module = import_module(widget_dir, fqmn)
+            if not module:
+                # error already logged
                 continue
-            if config.use_gui and button:
-                buttons.append(button)
-
-        # step 4: do special initialisation for wconfig submodules
-        elif submodule and submodule == 'wconfig':
-            _process_widget_config(module)
-            # don't log this action
-            continue
-
-        else:
-            logging.warning(
-                _('Missing function "initialize()" in imported module %s. '
-                  'Skip initialisation.'), fqmn)
-            continue
-
-        if config.use_gui and not submodule.endswith('codegen'):
-            logging.info('\t%s', module_name)
-        else:
-            logging.debug(_('Widget %s imported'), module_name)
+    
+            # step 2: use individual initialisation if available
+            if hasattr(module, 'initialize'):
+                button = module.initialize()
+                if config.use_gui and button:
+                    buttons[section].append(button)
+    
+            # step 3: import and initialise Python codegen as well as widget GUI elements
+            elif not submodule:
+                result, button = _init_codegen_gui(widget_dir, module_name)
+                if not result:
+                    continue
+                if config.use_gui and button:
+                    buttons[section].append(button)
+    
+            # step 4: do special initialisation for wconfig submodules
+            elif submodule and submodule == 'wconfig':
+                _process_widget_config(module)
+                # don't log this action
+                continue
+    
+            else:
+                logging.warning(_('Missing function "initialize()" in imported module %s. Skip initialisation.'), fqmn)
+                continue
+    
+            if config.use_gui and not submodule.endswith('codegen'):
+                logging.info('\t%s', module_name)
+            else:
+                logging.debug(_('Widget %s imported'), module_name)
     return buttons
 
 
-def _get_modulenames_from_file(filename):
-    """\
-    Return a list of module names read from given file.
+def _modulenames_from_file(filename, default_section):
+    """Return OrderedDict with module sections as key and assigned list of module names read from given file.
 
     @param filename: Absolute filename of the widgets.txt file
-    @type filename:  str
+    @param default_section: Section name to group all widgets, if no section has been found"""
+    content = OrderedDict()
 
-    @rtype: list[str] | None
-    """
     # test if the "widgets.txt" file exists
     if not os.path.isfile(filename):
         logging.debug(_('File %s not found.'), filename)
-        return []
+        return content
     try:
         widgets_file = open(filename)
-        module_list = widgets_file.readlines()
+        module_lines = widgets_file.readlines()
         widgets_file.close()
-    except (IOError, OSError), details:
-        logging.warning(
-            _("Can't read file %s file: %s"), filename, details)
-        return []
+    except EnvironmentError as details:
+        logging.warning( _("Can't read file %s file: %s"), filename, details )
+        return content
 
-    # remove empty lines, comment lines and tailing comments
-    cleaned = []
-    for module_name in module_list:
-        if not module_name or module_name.startswith('#'):
+    cursect = default_section
+
+    for line in module_lines:
+
+        # remove empty lines, comment lines and tailing comments
+        line = line.rstrip()
+        if not line:
+            continue
+        if line.startswith('#'):
             continue
-        module_name = module_name.split('#', 1)[0].strip()
-        module_name = module_name.strip()
-        if module_name:
-            cleaned.append(module_name)
 
-    return cleaned
+        if cursect not in content:
+            content[cursect] = []
+
+        # section heading
+        mo = rec_section.match(line)
+        if mo:
+            cursect = mo.group('section')
+            continue
+
+        mo = rec_module.match(line)
+        if mo:
+            content[cursect].append(mo.group('module'))
+
+    # remove empty sections
+    for section in list(content.keys()):
+        if not content[section]:
+            del content[section]
+
+    return content
 
 
 def _process_widget_config(module):
@@ -156,8 +177,7 @@ def _process_widget_config(module):
     # check mandatory attributes
     if 'wxklass' not in config_dict:
         logging.warning(
-            _('Missing mandatory configuration item "wxklass" in %s. '
-              'Ignoring whole configuration settings.'), name)
+            _('Missing mandatory configuration item "wxklass" in %s. Ignoring whole configuration settings.'), name)
         return False
 
     try:
@@ -173,8 +193,7 @@ def _process_widget_config(module):
 
 def _init_codegen_gui(widget_dir, widget_name):
     """\
-    Initialise Python code generator for the widget as well as widget
-    GUI parts.
+    Initialise Python code generator for the widget as well as widget GUI parts.
 
     @param widget_dir: Directory to search for widgets
     @type widget_dir:  str
@@ -193,25 +212,21 @@ def _init_codegen_gui(widget_dir, widget_name):
         # error already logged
         return False, None
     if not hasattr(codegen_module, 'initialize'):
-        logging.warning(
-            _('Missing function "initialize()" in imported '
-              'module %s. Skip initialisation.'), codegen_name)
+        logging.warning(_('Missing function "initialize()" in imported  module %s. Skip initialisation.'), codegen_name)
         return False, None
     codegen_module.initialize()
 
-    # initialise GUI part
-    if config.use_gui:
-        gui_name = '%s.%s' % (widget_name, widget_name)
-        gui_module = import_module(widget_dir, gui_name)
-        if not gui_module:
-            # error already logged
-            return False, None
-        if not hasattr(gui_module, 'initialize'):
-            logging.warning(
-                _('Missing function "initialize()" in imported '
-                  'module %s. Skip initialisation.'), gui_name)
-            return False, None
-        widget_button = gui_module.initialize()
+    ## initialise GUI part
+    #if config.use_gui:
+    gui_name = '%s.%s' % (widget_name, widget_name)
+    gui_module = import_module(widget_dir, gui_name)
+    if not gui_module:
+        # error already logged
+        return False, None
+    if not hasattr(gui_module, 'initialize'):
+        logging.warning(_('Missing function "initialize()" in imported module %s. Skip initialisation.'), gui_name)
+        return False, None
+    widget_button = gui_module.initialize()
 
     return True, widget_button
 
@@ -253,9 +268,7 @@ def import_module(widget_dir, module_name):
     if os.path.exists(zip_filename):
         # check ZIP file formally
         if not is_valid_zip(zip_filename, basemodule):
-            logging.warning(
-                _('ZIP file %s is not a valid ZIP file. Ignoring it.'),
-                zip_filename)
+            logging.warning( _('ZIP file %s is not a valid ZIP file. Ignoring it.'), zip_filename )
             zip_filename = None
         else:
             # add module temporarily to search path
@@ -266,25 +279,19 @@ def import_module(widget_dir, module_name):
     # import module
     try:
         try:
-            imported_module = __import__(module_name, {}, {},
-                                         ['just_not_empty'])
+            imported_module = __import__(module_name, {}, {}, ['just_not_empty'])
             return imported_module
         except ImportError:
-            logging.info(_('Module %s not found.'), module_name)
+            if config.debugging and not module_name.endswith(".wconfig") and not "lisp" in module_name and not "generic_calendar_ctrl" in module_name and not "property_grid" in module_name: raise
             return None
         except (AttributeError, NameError, SyntaxError, ValueError):
             if zip_filename:
-                logging.exception(
-                    _('Importing widget "%s" from ZIP file %s failed'),
-                    module_name, zip_filename)
+                logging.exception( _('Importing widget "%s" from ZIP file %s failed'), module_name, zip_filename )
             else:
-                logging.exception(
-                    _('Importing widget "%s" failed'), module_name)
+                logging.exception( _('Importing widget "%s" failed'), module_name )
             return None
         except:
-            logging.exception(
-                _('Unexpected error during import of widget module %s'),
-                module_name)
+            logging.exception( _('Unexpected error during import of widget module %s'), module_name )
             return None
 
     finally:
@@ -328,9 +335,7 @@ def is_valid_zip(filename, module_name):
             found_file = True
             break
     if not found_file:
-        logging.warning(
-            _('Missing file %s/codegen.py[co] in ZIP file %s. Ignoring '
-              'ZIP file.'), module_name, filename)
+        logging.warning(_('Missing file %s/codegen.py[co] in ZIP file %s. Ignoring ZIP file.'), module_name, filename)
         return False
 
     # check for GUI module
@@ -342,8 +347,7 @@ def is_valid_zip(filename, module_name):
             break
     if not found_file:
         logging.warning(
-            _('Missing file %s/%s.py[co] in ZIP file %s. Ignoring '
-              'ZIP file.'), module_name, module_name, filename)
+                _('Missing file %s/%s.py[co] in ZIP file %s. Ignoring ZIP file.'), module_name, module_name, filename)
         return False
     return True
 
@@ -365,19 +369,11 @@ def _get_zipfile_filelist(filename):
             zfile = zipfile.ZipFile(filename)
             namelist = zfile.namelist()
             zfile.close()
-        except zipfile.BadZipfile, inst:
-            logging.warning(
-                _('ZIP file %s is corrupt (%s). Ignoring ZIP file.'),
-                filename,
-                inst
-            )
+        except zipfile.BadZipfile as inst:
+            logging.warning( _('ZIP file %s is corrupt (%s). Ignoring ZIP file.'), filename, inst )
             return []
-        except zipfile.LargeZipFile, inst:
-            logging.warning(
-                _('ZIP file %s is bigger than 4GB (%s). Ignoring ZIP file.'),
-                filename,
-                inst
-            )
+        except zipfile.LargeZipFile as inst:
+            logging.warning( _('ZIP file %s is bigger than 4GB (%s). Ignoring ZIP file.'), filename, inst )
             return []
     finally:
         if zfile:
