@@ -1,7 +1,7 @@
 """\
 wxDialog widget configuration
 
-@copyright: 2014-2015 Carsten Grohmann
+@copyright: 2014-2016 Carsten Grohmann
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
@@ -15,8 +15,7 @@ config = {
             },
         'wxDIALOG_MODAL': {
             'desc': _('Show a modal dialog'),
-            'obsolete': _("This style is obsolete and doesn't do anything "
-                          "any more, don't use it in any new code."),
+            'obsolete': _("This style is obsolete and doesn't do anything any more, don't use it in any new code."),
             'supported_by': ('wx2',),
         },
         'wxRESIZE_BOX': {
@@ -28,7 +27,6 @@ config = {
             'desc': 'Display a thick frame around the window.',
             'rename_to': 'wxRESIZE_BORDER',
         },
-        # wxNO_3D -> config.widget_config
         'wxDIALOG_NO_PARENT': {
             'desc': _("By default, a dialog created with a NULL parent "
                       "window will be given the application's top level "
@@ -41,12 +39,11 @@ config = {
         # - wxNO_FULL_REPAINT_ON_RESIZE
         # - wxCLIP_CHILDREN
     },
-    'box_label': _('Style'),
     'style_list': ['wxDEFAULT_DIALOG_STYLE', 'wxDIALOG_MODAL', 'wxCAPTION',
                    'wxSYSTEM_MENU', 'wxCLOSE_BOX', 'wxRESIZE_BOX',
                    'wxMAXIMIZE_BOX', 'wxMINIMIZE_BOX', 'wxTHICK_FRAME',
-                   'wxRESIZE_BORDER', 'wxSTAY_ON_TOP', 'wxNO_3D',
-                   'wxDIALOG_NO_PARENT', 'wxNO_FULL_REPAINT_ON_RESIZE',
+                   'wxRESIZE_BORDER', 'wxSTAY_ON_TOP',
+                   'wxDIALOG_NO_PARENT',
                    'wxFULL_REPAINT_ON_RESIZE', 'wxCLIP_CHILDREN'],
     'events': {
         'default': {
