@@ -2,7 +2,7 @@
 Perl code generator functions for wxFrame objects
 
 @copyright: 2002-2007 Alberto Griggio
-@copyright: 2013-2015 Carsten Grohmann
+@copyright: 2013-2016 Carsten Grohmann
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
@@ -11,9 +11,7 @@ import wcodegen
 
 
 class PerlFrameCodeGenerator(wcodegen.PerlWidgetCodeWriter):
-    new_signature = [
-        '$parent', '$id', '$title', '$pos', '$size', '$style', '$name'
-    ]
+    new_signature = ['$parent', '$id', '$title', '$pos', '$size', '$style', '$name']
 
     def get_code(self, obj):
         return [], [], [], []  # the frame can't be a children
@@ -21,13 +19,11 @@ class PerlFrameCodeGenerator(wcodegen.PerlWidgetCodeWriter):
     def get_properties_code(self, obj):
         out = []
         append = out.append
-        title = obj.properties.get('title')
-        if title:
-            append('$self->SetTitle(%s);\n' % self.codegen.quote_str(title))
-        icon = obj.properties.get('icon')
-        if icon:
-            stmt_icon = self.generate_code_bitmap(icon, obj.preview)
-            out.append('my $icon = &Wx::wxNullIcon();\n')
+        if obj.title:
+            append('$self->SetTitle(%s);\n' % self.codegen.quote_str(obj.title))
+        if obj.icon:
+            stmt_icon = self.generate_code_bitmap(obj.icon)
+            out.append('my $icon = &Wx::wxNullIcon;\n')
             out.append('$icon->CopyFromBitmap(%s);\n' % stmt_icon)
             out.append('$self->SetIcon($icon);\n')
         out.extend(self.codegen.generate_common_properties(obj))
@@ -35,21 +31,14 @@ class PerlFrameCodeGenerator(wcodegen.PerlWidgetCodeWriter):
 
     def get_layout_code(self, obj):
         ret = ['$self->Layout();\n']
-        try:
-            if int(obj.properties['centered']):
-                ret.append('$self->Centre();\n')
-        except (KeyError, ValueError):
-            pass
+        if obj.centered:
+            ret.append('$self->Centre();\n')
         return ret
 
-# end of class PerlFrameCodeGenerator
-
 
 class PerlMDIChildFrameCodeGenerator(PerlFrameCodeGenerator):
     import_modules = ['Wx::MDI']
 
-# end of class PerlMDIChildFrameCodeGenerator
-
 
 def initialize():
     klass = 'wxFrame'
@@ -65,5 +54,5 @@ def initialize():
         awh('wxFrame', PerlFrameCodeGenerator(klass))
         awh('wxMDIChildFrame', PerlMDIChildFrameCodeGenerator(klass))
 
-        aph = plgen.add_property_handler
-        aph('menubar', plgen.DummyPropertyHandler)
+        #aph = plgen.add_property_handler
+        #aph('menubar', plgen.DummyPropertyHandler)
