@@ -17,25 +17,22 @@ config = {
             'desc': _('Show Monday as the first day in the week')
         },
         'wxCAL_SHOW_HOLIDAYS': {
-            'desc': _('Show Monday as the first day in the week')
+            'desc': _('Highlight holidays in the calendar (only generic)')
         },
         'wxCAL_NO_YEAR_CHANGE': {
             'desc': _('Disable the year changing')
         },
         'wxCAL_NO_MONTH_CHANGE': {
-            'desc': _('Disable the month (and, implicitly, the year) '
-                      'changing')
+            'desc': _('Disable the month (and, implicitly, the year) changing')
         },
         'wxCAL_SHOW_SURROUNDING_WEEKS': {
-            'desc': _('Show the neighbouring weeks in the previous and next '
-                      'months')
+            'desc': _('Show the neighbouring weeks in the previous and next months')
         },
         'wxCAL_SEQUENTIAL_MONTH_SELECTION': {
-            'desc': _('Use alternative, more compact, style for the month '
-                      'and year selection controls.')
+            'desc': _('Use alternative, more compact, style for the month and year selection controls.')
         },
     },
-    'box_label': _('Style'),
+    'default_style': 'wxCAL_SHOW_HOLIDAYS',
     'style_list': ['wxCAL_SUNDAY_FIRST', 'wxCAL_MONDAY_FIRST',
                    'wxCAL_SHOW_HOLIDAYS', 'wxCAL_NO_YEAR_CHANGE',
                    'wxCAL_NO_MONTH_CHANGE', 'wxCAL_SHOW_SURROUNDING_WEEKS',
