@@ -1,7 +1,8 @@
 """\
 wxGrid widget configuration
 
-@copyright: 2015 Carsten Grohmann
+@copyright: 2016 Carsten Grohmann
+@copyright: 2016 Dietmar Schwertberger
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
@@ -22,6 +23,9 @@ config = {
         'EVT_GRID_CMD_LABEL_LEFT_DCLICK': {},
         'EVT_GRID_CMD_LABEL_RIGHT_DCLICK': {},
         'EVT_GRID_CMD_CELL_CHANGE': {},
+        
+        'EVT_GRID_CMD_CELL_CHANGING': {},  # for Phoenix: before change
+        'EVT_GRID_CMD_CELL_CHANGED': {},   # for Phoenix: after change
         'EVT_GRID_CMD_SELECT_CELL': {},
         'EVT_GRID_CMD_EDITOR_HIDDEN': {},
         'EVT_GRID_CMD_EDITOR_SHOWN': {},
