@@ -1,7 +1,7 @@
 """\
 wxPanel widget configuration
 
-@copyright: 2014-2015 Carsten Grohmann
+@copyright: 2014-2016 Carsten Grohmann
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
@@ -9,15 +9,14 @@ wxPanel widget configuration
 config = {
     'wxklass': 'wxPanel',
     'style_defs': {},
-    'box_label': _('Style'),
     'style_list': ['wxSIMPLE_BORDER', 'wxBORDER_SIMPLE',
                    'wxDOUBLE_BORDER', 'wxBORDER_DOUBLE',
                    'wxSUNKEN_BORDER', 'wxBORDER_SUNKEN',
                    'wxRAISED_BORDER', 'wxBORDER_RAISED',
                    'wxSTATIC_BORDER', 'wxBORDER_STATIC',
                    'wxNO_BORDER', 'wxBORDER_NONE',
-                   'wxNO_3D', 'wxTAB_TRAVERSAL', 'wxWANTS_CHARS',
-                   'wxNO_FULL_REPAINT_ON_RESIZE', 'wxFULL_REPAINT_ON_RESIZE',
+                   'wxTAB_TRAVERSAL', 'wxWANTS_CHARS',
+                   'wxFULL_REPAINT_ON_RESIZE',
                    'wxCLIP_CHILDREN'],
     'events': {
         'EVT_NAVIGATION_KEY': {
