@@ -1,7 +1,8 @@
 """\
 wxComboBox widget configuration
 
-@copyright: 2015 Carsten Grohmann
+@copyright: 2016 Carsten Grohmann
+@copyright: 2017 Dietmar Schwertberger
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
@@ -9,15 +10,14 @@ config = {
     'wxklass': 'wxRadioBox',
     'style_defs': {
         'wxRA_SPECIFY_ROWS': {
-            'desc': _('The major dimension parameter refers to the maximum '
-                      'number of rows.'),
+            'desc': _('The major dimension parameter refers to the maximum number of rows.'),
+            'exclude': 'wxRA_SPECIFY_COLS',
         },
         'wxRA_SPECIFY_COLS': {
-            'desc': _('The major dimension parameter refers to the maximum '
-                      'number of columns.'),
+            'desc': _('The major dimension parameter refers to the maximum number of columns.'),
+            'exclude': 'wxRA_SPECIFY_ROWS',
         },
     },
-    'box_label': _('Style'),
     'style_list': ['wxRA_SPECIFY_ROWS', 'wxRA_SPECIFY_COLS'],
     'events': {
         'EVT_RADIOBOX': {},
