@@ -1,7 +1,7 @@
 """\
 wxRadioButton widget configuration
 
-@copyright: 2014-2015 Carsten Grohmann
+@copyright: 2014-2016 Carsten Grohmann
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
@@ -9,8 +9,7 @@ config = {
     'wxklass': 'wxRadioButton',
     'style_defs': {
         'wxRB_GROUP': {
-            'desc': _('Marks the beginning of a new group of radio '
-                      'buttons.'),
+            'desc': _('Marks the beginning of a new group of radio buttons.'),
         },
         'wxRB_SINGLE': {
             'desc': _('In some circumstances, radio buttons that are not '
@@ -20,12 +19,10 @@ config = {
                       'the mutually-exclusive group behaviour yourself.'),
         },
         'wxRB_USE_CHECKBOX': {
-            'desc': _('Use a checkbox button instead of radio button ('
-                      'currently supported only on PalmOS).'),
+            'desc': _('Use a checkbox button instead of radio button (currently supported only on PalmOS).'),
             'supported_by': ('wx2',),
         },
     },
-    'box_label': _('Style'),
     'style_list': ['wxRB_GROUP', 'wxRB_SINGLE', 'wxRB_USE_CHECKBOX'],
     'events': {
         'EVT_RADIOBUTTON': {},
