@@ -1,7 +1,7 @@
 """\
 wxSlider widget configuration
 
-@copyright: 2014-2015 Carsten Grohmann
+@copyright: 2014-2016 Carsten Grohmann
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
@@ -11,9 +11,11 @@ config = {
         'wxSL_HORIZONTAL': {
             'desc': _('Displays the slider horizontally (this is the '
                       'default).'),
+            'exclude': 'wxSL_VERTICAL',
         },
         'wxSL_VERTICAL': {
             'desc': _('Displays the slider vertically.'),
+            'exclude': 'wxSL_HORIZONTAL',
         },
         'wxSL_AUTOTICKS': {
             'desc': _('Displays tick marks. Windows only.'),
@@ -56,7 +58,6 @@ config = {
             'exclude': 'wxSL_SELRANGE',
         },
     },
-    'box_label': _('Style'),
     'default_style': 'wxSL_HORIZONTAL',
     'style_list': ['wxSL_HORIZONTAL', 'wxSL_VERTICAL',
                    'wxSL_AUTOTICKS',
