@@ -1,7 +1,7 @@
 """\
 wxSpinCtrl widget configuration
 
-@copyright: 2014-2015 Carsten Grohmann
+@copyright: 2014-2016 Carsten Grohmann
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
@@ -129,7 +129,6 @@ config = {
                       'to be capitalized.'),
         },
     },
-    'box_label': _('Style'),
     'default_style': 'wxSP_ARROW_KEYS',
     'style_list': ['wxSP_ARROW_KEYS', 'wxSP_WRAP',
                    'wxTE_PROCESS_ENTER', 'wxTE_PROCESS_TAB',
@@ -140,7 +139,7 @@ config = {
                    'wxTE_LINEWRAP', 'wxTE_CHARWRAP', 'wxTE_WORDWRAP',
                    'wxTE_BESTWRAP', 'wxTE_CAPITALIZE', 'wxNO_BORDER'],
     'events': {
-        'EVT_SPINCTRL': {
+        'EVT_SPINCTRLDOUBLE': {
             'type': 'wxSpinEvent',
         },
     },
