@@ -1,7 +1,7 @@
 """\
 wxStaticBitmap widget configuration
 
-@copyright: 2014-2015 Carsten Grohmann
+@copyright: 2014-2016 Carsten Grohmann
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
@@ -10,15 +10,12 @@ config = {
     'wxklass': 'wxStaticBitmap',
     'style_defs': {
     },
-    'box_label': _('Style'),
     'style_list': ['wxSIMPLE_BORDER', 'wxBORDER_SIMPLE',
                    'wxSUNKEN_BORDER', 'wxBORDER_SUNKEN',
                    'wxRAISED_BORDER', 'wxBORDER_RAISED',
                    'wxSTATIC_BORDER', 'wxBORDER_STATIC',
                    'wxDOUBLE_BORDER', 'wxBORDER_DOUBLE',
                    'wxNO_BORDER',     'wxBORDER_NONE',
-                   'wxNO_3D',
                    'wxTAB_TRAVERSAL', 'wxWANTS_CHARS',
-                   'wxNO_FULL_REPAINT_ON_RESIZE',
                    'wxFULL_REPAINT_ON_RESIZE', 'wxCLIP_CHILDREN'],
 }
