@@ -2,7 +2,7 @@
 Lisp generator functions for wxStaticText objects
 
 @copyright: 2002-2004 D. H. aka crazyinsomniac on sourceforge
-@copyright: 2014-2015 Carsten Grohmann
+@copyright: 2014-2016 Carsten Grohmann
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
@@ -11,10 +11,7 @@ import wcodegen
 
 
 class LispStaticTextGenerator(wcodegen.LispWidgetCodeWriter):
-    tmpl = '(setf %(name)s (%(klass)s_Create %(parent)s %(id)s ' \
-           '%(label)s -1 -1 -1 -1 %(style)s))\n'
-
-# end of class LispStaticTextGenerator
+    tmpl = '(setf %(name)s (%(klass)s_Create %(parent)s %(id)s %(label)s -1 -1 -1 -1 %(style)s))\n'
 
 
 def initialize():
