@@ -4,14 +4,14 @@ Toolbar widget module initialization
 @copyright: 2002-2007 Alberto Griggio
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
-
+from __future__ import absolute_import
 
 def initialize():
     import config
-    import codegen
+    from . import codegen
     codegen.initialize()
-    if config.use_gui:
-        import toolbar
-        global EditToolBar
-        EditToolBar = toolbar.EditToolBar
-        return toolbar.initialize()
+    #if config.use_gui:
+    from . import toolbar
+    global EditToolBar
+    EditToolBar = toolbar.EditToolBar
+    return toolbar.initialize()
