@@ -4,7 +4,8 @@ Converts an XRC resource file (in a format wxGlade likes, i.e. all windows
 inside sizers, no widget unknown to wxGlade, ...) into a WXG file.
 
 @copyright: 2002-2007 Alberto Griggio
-@copyright: 2014-2015 Carsten Grohmann
+@copyright: 2014-2016 Carsten Grohmann
+@copyright: 2017 Dietmar Schwertberger
 @license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
@@ -15,12 +16,11 @@ import os.path
 import sys
 import time
 
-__version__ = '0.0.5'
-_name = 'xrc2wxg'
-"""\
-Application name
-"""
+__version__ = '0.0.6'
+_name = 'xrc2wxg'  # Application name
 
+
+# Mapping of default attribute names from XRC to WXG; see _class_props
 _default_props = {
     'bg': 'background',
     'content': 'choices',
@@ -31,12 +31,9 @@ _default_props = {
     'item': 'choice',
     'sashpos': 'sash_pos',
 }
-"""\
-Mapping of default attribute names from XRC to WXG
 
-@see: L{_class_props}
-"""
 
+# Mapping of class specific attribute names from XRC to WXG. The class names are XRC class names. see _default_props
 _class_props = {
     'wxMenuItem': {
         'help': 'help_str',
@@ -48,43 +45,29 @@ _class_props = {
         'toggle': 'type',
     }
 }
-"""\
-Mapping of class specific attribute names from XRC to WXG.
 
-The class names are XRC class names.
-
-@see: L{_default_props}
-"""
 
+# Counter to create unique names
 _counter_name = 1
-"""\
-Counter to create unique names
-"""
 
+# Supported widgets
 _widgets = [
-    'wxBitmapButton', 'wxBoxSizer', 'wxButton', 'wxCheckBox', 'wxChoice',
-    'wxComboBox', 'wxDialog', 'wxFlexGridSizer', 'wxFrame', 'wxGauge',
-    'wxGrid', 'wxGridSizer', 'wxListBox', 'wxListCtrl', 'wxMenuBar', 'wxMenu'
-    'wxNotebook', 'wxPanel', 'wxRadioBox', 'wxRadioButton',
-    'wxScrolledWindow', 'wxSlider', 'wxSpinCtrl', 'wxSplitterWindow',
-    'wxStaticBitmap', 'wxStaticBoxSizer', 'wxStaticLine', 'wxStaticText',
-    'wxStatusBar', 'wxTextCtrl', 'wxToggleButton', 'wxToolBar', 'wxTreeCtrl',
+    'wxBitmapButton', 'wxBoxSizer', 'wxButton', 'wxCalendarCtrl',
+    'wxCheckBox', 'wxCheckListBox', 'wxChoice', 'wxComboBox',
+    'wxDatePickerCtrl', 'wxDialog', 'wxFlexGridSizer', 'wxFrame',
+    'wxGauge', 'wxGrid', 'wxGridSizer', 'wxListBox', 'wxListCtrl',
+    'wxMenuBar', 'wxMenu', 'wxNotebook', 'wxPanel', 'wxRadioBox',
+    'wxRadioButton', 'wxScrolledWindow', 'wxSlider', 'wxSpinButton',
+    'wxSpinCtrl', 'wxSplitterWindow', 'wxStaticBitmap', 'wxStaticBoxSizer',
+    'wxStaticLine', 'wxStaticText', 'wxStatusBar', 'wxTextCtrl',
+    'wxToggleButton', 'wxToolBar', 'wxTreeCtrl',
 ]
-"""\
-Supported widgets
-"""
 
-_special_class_names = [
-    'notebookpage', 'separator', 'sizeritem', 'spacer', 'tool',
-]
-"""\
-Widget names with special meaning
-"""
+# Widget names with special meaning
+_special_class_names = ['notebookpage', 'separator', 'sizeritem', 'spacer', 'tool']
 
+# Write a timestamp in the output file
 _write_timestamp = True
-"""\
-Write a timestamp in the output file
-"""
 
 
 def get_child_elems(node):
@@ -102,17 +85,8 @@ def get_text_elems(node):
 
 
 def convert(filename, output_file):
-    """\
-    Convert the given XRC file to a wxGlade file
-
-    @note: The output content is UTF-8 encoded.
-
-    @param filename: Source filename
-    @type filename: str
-
-    @param output_file: Filename, file or file-like object
-    @type output_file:  str | StringIO
-    """
+    """Convert the given XRC file to a UTF-8 encoded wxGlade file
+    output_file: Filename, file or file-like object"""
     global _counter_name
     _counter_name = 1
 
@@ -123,8 +97,8 @@ def convert(filename, output_file):
     fix_class_properties(document)
     fix_widgets(document)
     fix_encoding(filename, document)
-    if not hasattr(output_file, 'write'):
-        output_file = open(output_file, 'w')
+    if not hasattr(output_file, 'write') and not isinstance(output_file, list):
+        output_file = open(output_file, 'wb')
         write_output(document, output_file)
         output_file.close()
     else:
@@ -132,15 +106,11 @@ def convert(filename, output_file):
 
 
 def write_output(document, output):
-    """\
-    Writes an UTF-8 encoded pretty-printed XML copy of the given document to
-    the output object.
-    """
+    "Writes an UTF-8 encoded pretty-printed XML copy of the given document to the output object."
     dom_copy = xml.dom.minidom.Document()
 
     if _write_timestamp:
-        msg = ' generated by %s %s on %s ' % (
-            _name, __version__, time.asctime())
+        msg = ' generated by %s %s on %s '%( _name, __version__, time.asctime() )
     else:
         msg = ' generated by xrc2wxg '
 
@@ -153,8 +123,11 @@ def write_output(document, output):
         # ignore empty lines
         if not line.strip():
             continue
-        output.write(line)
-        output.write('\n')
+        if hasattr(output, "write"):
+            output.write(line)
+            output.write(b'\n')
+        else:
+            output.append(line+b'\n')
 
     dom_copy.unlink()
 
@@ -172,11 +145,7 @@ def set_base_classes(document):
 
 
 def fix_default_properties(document):
-    """\
-    Rename generic properties
-
-    @see: L{_default_props}
-    """
+    "Rename generic properties; see: _default_props"
     # special case...
     for elem in document.getElementsByTagName('disabled'):
         elem.tagName = 'disabled_bitmap'
@@ -194,16 +163,13 @@ def fix_default_properties(document):
                     elem.firstChild.data = u'0'
 
     document.documentElement.tagName = 'application'
-    if document.documentElement.hasAttribute('version'):
-        document.documentElement.removeAttribute('version')
+    for attribute in ['version', 'xmlns']:
+        if document.documentElement.hasAttribute(attribute):
+            document.documentElement.removeAttribute(attribute)
 
 
 def fix_class_properties(document):
-    """\
-    Rename class specific properties
-
-    @see: L{_class_props}
-    """
+    "Rename class specific properties; see: _class_props"
     for element in document.getElementsByTagName('object'):
         klass = element.getAttribute('class')
         if not klass or klass not in _class_props:
@@ -232,13 +198,12 @@ def fix_custom_widgets(document):
     for elem in document.getElementsByTagName('object'):
         klass = elem.getAttribute('class')
         if klass not in _widgets and klass not in _special_class_names:
+            logging.warning('Unknown widget "%s" - fallback to generic widget "CustomWidget"' % klass)
             elem.setAttribute('base', 'CustomWidget')
             args = document.createElement('arguments')
             for child in get_child_elems(elem):
-                # if child is a 'simple' attribute, i.e
-                # <child>value</child>, convert it to an 'argument'
-                if len(child.childNodes) == 1 and \
-                   child.firstChild.nodeType == child.TEXT_NODE:
+                # if child is a 'simple' attribute, i.e <child>value</child>, convert it to an 'argument'
+                if len(child.childNodes) == 1 and child.firstChild.nodeType == child.TEXT_NODE:
                     arg = document.createElement('argument')
                     arg.appendChild(document.createTextNode(
                         child.tagName + ': ' + child.firstChild.data))
@@ -268,9 +233,8 @@ def fix_flag_property(document):
         elem.firstChild.data = tmp.replace('GROW', 'EXPAND')
         if elem.firstChild.data.find('wxALIGN_CENTER_HORIZONTAL') < 0 and \
            elem.firstChild.data.find('wxALIGN_CENTER_VERTICAL') < 0:
-            elem.firstChild.data = elem.firstChild.data.replace(
-                'wxALIGN_CENTER', 'wxALIGN_CENTER_HORIZONTAL|'
-                                  'wxALIGN_CENTER_VERTICAL')
+            elem.firstChild.data = elem.firstChild.data.replace( 'wxALIGN_CENTER', 'wxALIGN_CENTER_HORIZONTAL|'
+                                                                 'wxALIGN_CENTER_VERTICAL' )
 
 
 def fix_menubars(document):
@@ -287,8 +251,7 @@ def fix_menubars(document):
 
 
 def fix_menus(document, menubar):
-    """\
-    Rearrange the wxMenu elements
+    """Rearrange the wxMenu elements
 
     All menus of a wxMenuBar have to span by <menus> and </menus>::
         <menus>
@@ -298,8 +261,7 @@ def fix_menus(document, menubar):
             <menu>
             ...
             </menu>
-        </menus>
-    """
+        </menus>"""
 
     def ismenu(elem):
         return elem.getAttribute('class') == 'wxMenu'
@@ -309,8 +271,7 @@ def fix_menus(document, menubar):
     xrc_menus = filter(ismenu, get_child_elems(menubar))
     for menu in xrc_menus:
         try:
-            label = [c for c in get_child_elems(menu)
-                     if c.tagName == 'label'][0]
+            label = [c for c in get_child_elems(menu) if c.tagName == 'label'][0]
             label = label.firstChild.data
         except IndexError:
             label = ''
@@ -346,8 +307,7 @@ def fix_sub_menus(document, menu, new_menu):
             elem.tagName = 'menu'
             elem.setAttribute('name', child.getAttribute('name'))
             try:
-                label = [c for c in get_child_elems(child) if
-                         c.tagName == 'label'][0]
+                label = [c for c in get_child_elems(child) if c.tagName == 'label'][0]
                 label = label.firstChild.data
             except IndexError:
                 label = ''
@@ -357,12 +317,14 @@ def fix_sub_menus(document, menu, new_menu):
             new_menu.appendChild(elem)
 
 
-def fix_toolbars(document):
-    def istoolbar(elem):
-        return elem.getAttribute('class') == 'wxToolBar'
+def _get_elements_by_class(document, classnames):
+    if isinstance(classnames, str):
+        classnames = (classnames,)
+    return [node for node in document.getElementsByTagName('object') if node.getAttribute('class') in classnames]
 
-    toolbars = filter(istoolbar, document.getElementsByTagName('object'))
-    for tb in toolbars:
+
+def fix_toolbars(document):
+    for tb in _get_elements_by_class(document, 'wxToolBar'):
         fix_tools(document, tb)
         if tb.parentNode is not document.documentElement:
             tb_prop = document.createElement('toolbar')
@@ -372,8 +334,7 @@ def fix_toolbars(document):
 
 def fix_tools(document, toolbar):
     tools = document.createElement('tools')
-    for tool in [c for c in get_child_elems(toolbar) if
-                 c.tagName == 'object']:
+    for tool in [c for c in get_child_elems(toolbar) if c.tagName == 'object']:
         if tool.getAttribute('class') == 'tool':
             new_tool = document.createElement('tool')
             tool_id = document.createElement('id')
@@ -398,18 +359,12 @@ def fix_tools(document, toolbar):
 
 
 def fix_notebooks(document):
-    def ispage(node):
-        return node.getAttribute('class') == 'notebookpage'
 
-    def isnotebook(node):
-        return node.getAttribute('class') == 'wxNotebook'
-
-    for nb in filter(isnotebook, document.getElementsByTagName('object')):
-        pages = filter(ispage, get_child_elems(nb))
+    for nb in _get_elements_by_class(document, 'wxNotebook'):
+        pages = [node for node in get_child_elems(nb) if node.getAttribute('class')=='notebookpage']
         tabs = document.createElement('tabs')
         try:
-            us = filter(lambda n: n.tagName == 'usenotebooksizer',
-                        get_child_elems(nb))[0]
+            us = [node for node in get_child_elems(nb) if node.tagName=='usenotebooksizer'][0]
             nb.removeChild(us).unlink()
         except IndexError:
             pass
@@ -429,21 +384,14 @@ def fix_notebooks(document):
 
 
 def fix_splitters(document):
-    def issplitter(node):
-        return node.getAttribute('class') == 'wxSplitterWindow'
-
-    def ispane(node):
-        return node.tagName == 'object'
-
-    for sp in filter(issplitter, document.getElementsByTagName('object')):
-        panes = filter(ispane, get_child_elems(sp))
+    for sp in _get_elements_by_class(document, 'wxSplitterWindow'):
+        panes = [node for node in get_child_elems(sp) if node.tagName=='object']
         assert len(panes) <= 2, "Splitter window with more than 2 panes!"
         for i, pane in enumerate(panes):
             e = document.createElement('window_%s' % (i + 1))
             e.appendChild(document.createTextNode(pane.getAttribute('name')))
             sp.insertBefore(e, sp.firstChild)
-        for orient in filter(lambda n: n.tagName == 'orientation',
-                             get_child_elems(sp)):
+        for orient in filter( lambda n: n.tagName == 'orientation', get_child_elems(sp) ):
             if orient.firstChild.data == 'vertical':
                 orient.firstChild.data = 'wxVERTICAL'
             elif orient.firstChild.data == 'horizontal':
@@ -451,24 +399,16 @@ def fix_splitters(document):
 
 
 def fix_fake_panels(document):
-    def isframe(node):
-        return node.getAttribute('class') == 'wxFrame'
-
-    for frame in filter(isframe, document.getElementsByTagName('object')):
+    for frame in _get_elements_by_class(document, 'wxFrame'):
         for c in get_child_elems(frame):
-            if c.tagName == 'object' and c.getAttribute('class') == 'wxPanel' \
-                    and c.getAttribute('name') == '':
+            if c.tagName == 'object' and c.getAttribute('class') == 'wxPanel' and c.getAttribute('name') == '':
                 elems = get_child_elems(c)
-                if len(elems) == 1 and \
-                   elems[0].getAttribute('class').find('Sizer') != -1:
+                if len(elems) == 1 and elems[0].getAttribute('class').find('Sizer') != -1:
                     frame.replaceChild(elems[0], c)
 
 
 def fix_spacers(document):
-    def isspacer(node):
-        return node.getAttribute('class') == 'spacer'
-
-    for spacer in filter(isspacer, document.getElementsByTagName('object')):
+    for spacer in _get_elements_by_class(document, 'spacer'):
         spacer.setAttribute('name', 'spacer')
         spacer.setAttribute('base', 'EditSpacer')
         sizeritem = document.createElement('object')
@@ -490,10 +430,7 @@ def fix_spacers(document):
 
 
 def fix_scrolled_windows(document):
-    def isscrollwin(node):
-        return node.getAttribute('class') == 'wxScrolledWindow'
-
-    for sw in filter(isscrollwin, document.getElementsByTagName('object')):
+    for sw in _get_elements_by_class(document, 'wxScrolledWindow'):
         e = document.createElement('scrollable')
         e.appendChild(document.createTextNode('1'))
         sw.insertBefore(e, sw.firstChild)
@@ -517,11 +454,7 @@ def fix_toplevel_names(document):
 
 
 def fix_sliders(document):
-    def isslider(node):
-        klass = node.getAttribute('class')
-        return klass == 'wxSlider' or klass == 'wxSpinCtrl'
-
-    for slider in filter(isslider, document.getElementsByTagName('object')):
+    for slider in _get_elements_by_class(document, ('wxSlider', 'wxSpinCtrl')): 
         v1, v2 = 0, 100
         for child in get_child_elems(slider):
             if child.tagName == 'min':
@@ -536,8 +469,7 @@ def fix_sliders(document):
 
 
 def fix_statusbar(document):
-    """\
-    Rearrange the wxStatusBar elements
+    """Rearrange the wxStatusBar elements
 
     XRC format::
 
@@ -623,12 +555,9 @@ def fix_encoding(filename, document):
     # if it's not specified, try to find a child of the root called
     # 'encoding': I don't know why, but XRCed does this
     for child in document.documentElement.childNodes:
-        if child.nodeType == child.ELEMENT_NODE and \
-           child.tagName == 'encoding':
-            if child.firstChild is not None and \
-               child.firstChild.nodeType == child.TEXT_NODE:
-                document.documentElement.setAttribute(
-                    'encoding', child.firstChild.data)
+        if child.nodeType == child.ELEMENT_NODE and child.tagName == 'encoding':
+            if child.firstChild is not None and child.firstChild.nodeType == child.TEXT_NODE:
+                document.documentElement.setAttribute( 'encoding', child.firstChild.data )
             document.documentElement.removeChild(child)
 
 
@@ -641,13 +570,12 @@ OPTIONS:
 
 If WXG_FILE is not given, it defaults to INPUT_FILE.wxg
     """ % _name
-    print msg
+    print( msg)
     sys.exit(1)
 
 
 def print_exception():
-    msg = """\
-An error occurred while trying to convert the XRC file.
+    msg = """An error occurred while trying to convert the XRC file.
 \n
 If you think this is a bug, or if you want to know more about the cause of the
 error, run this script again in debug mode (-d switch). If you find a bug,
